pub struct CreateNewSigningKeyParams {
pub account_sid: String,
pub friendly_name: Option<String>,
}Expand description
struct for passing parameters to the method create_new_signing_key
Fields
account_sid: StringThe SID of the Account that will be responsible for the new Key resource.
friendly_name: Option<String>A descriptive string that you create to describe the resource. It can be up to 64 characters long.