pub struct UpdateShortCodeParams {
pub account_sid: String,
pub sid: String,
pub friendly_name: Option<String>,
pub api_version: Option<String>,
pub sms_url: Option<String>,
pub sms_method: Option<String>,
pub sms_fallback_url: Option<String>,
pub sms_fallback_method: Option<String>,
}Expand description
struct for passing parameters to the method update_short_code
Fields
account_sid: StringThe SID of the Account that created the ShortCode resource(s) to update.
sid: StringThe Twilio-provided string that uniquely identifies the ShortCode resource to update
friendly_name: Option<String>A descriptive string that you created to describe this resource. It can be up to 64 characters long. By default, the FriendlyName is the short code.
api_version: Option<String>The API version to use to start a new TwiML session. Can be: 2010-04-01 or 2008-08-01.
sms_url: Option<String>The URL we should call when receiving an incoming SMS message to this short code.
sms_method: Option<String>The HTTP method we should use when calling the sms_url. Can be: GET or POST.
sms_fallback_url: Option<String>The URL that we should call if an error occurs while retrieving or executing the TwiML from sms_url.
sms_fallback_method: Option<String>The HTTP method that we should use to call the sms_fallback_url. Can be: GET or POST.