pub struct CreateValidationRequestParams {
pub account_sid: String,
pub phone_number: String,
pub friendly_name: Option<String>,
pub call_delay: Option<i32>,
pub extension: Option<String>,
pub status_callback: Option<String>,
pub status_callback_method: Option<String>,
}Expand description
struct for passing parameters to the method create_validation_request
Fields
account_sid: StringThe SID of the Account responsible for the new caller ID resource.
phone_number: StringThe phone number to verify in E.164 format, which consists of a + followed by the country code and subscriber number.
friendly_name: Option<String>A descriptive string that you create to describe the new caller ID resource. It can be up to 64 characters long. The default value is a formatted version of the phone number.
call_delay: Option<i32>The number of seconds to delay before initiating the verification call. Can be an integer between 0 and 60, inclusive. The default is 0.
extension: Option<String>The digits to dial after connecting the verification call.
status_callback: Option<String>The URL we should call using the status_callback_method to send status information about the verification process to your application.
status_callback_method: Option<String>The HTTP method we should use to call status_callback. Can be: GET or POST, and the default is POST.